@@ -28,21 +28,15 @@ def dry_run(*, project_id, dataset_id, table_id, session: bigframes.session.Sess
 
 
 if __name__ == "__main__":
-    (
-        project_id,
-        dataset_id,
-        table_id,
-        session,
-        suffix,
-    ) = utils.get_configuration(include_table_id=True)
+    config = utils.get_configuration(include_table_id=True)
     current_path = pathlib.Path(__file__).absolute()
 
     utils.get_execution_time(
         dry_run,
         current_path,
-        suffix,
-        project_id=project_id,
-        dataset_id=dataset_id,
-        table_id=table_id,
-        session=session,
+        config.benchmark_suffix,
+        project_id=config.project_id,
+        dataset_id=config.dataset_id,
+        table_id=config.table_id,
+        session=config.session,
     )
